@@ -29,7 +29,6 @@
 #include <gnome.h>
 
 #include "gst.h"
-#include "gst-hig-dialog.h"
 #include "gst-report-hook.h"
 #include "boot-druid.h"
 #include "boot-settings.h"
@@ -406,14 +405,14 @@ on_boot_delete_clicked (GtkButton *button, gpointer data)
 
 	count = boot_image_count (gst_xml_doc_get_root (tool->config));
 	if (count <= 1) {
-		d = gst_hig_dialog_new (GTK_WINDOW (tool->main_dialog),
-					GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-					GST_HIG_MESSAGE_ERROR,
-					_("Error deleting boot image"),
-					_("Without at least one boot image "
-					  "your computer will not start"),
-					GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
-					NULL);
+		d = gtk_message_dialog_new (GTK_WINDOW (tool->main_dialog),
+					    GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+					    GTK_MESSAGE_ERROR,
+					    GTK_BUTTONS_CLOSE,
+					    _("Error deleting boot image"));
+		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (d),
+							  _("Without at least one boot image "
+							    "your computer will not start"));
 		gtk_dialog_run (GTK_DIALOG (d));
 		gtk_widget_destroy (d);
 		return;
@@ -427,19 +426,19 @@ on_boot_delete_clicked (GtkButton *button, gpointer data)
 	
 	label = gst_xml_get_child_content (node, "label");
 
-	d = gst_hig_dialog_new (GTK_WINDOW (tool->main_dialog),
-				GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-				GST_HIG_MESSAGE_QUESTION,
-				NULL,
-				_("This may leave this operating system unbootable"),
+	d = gtk_message_dialog_new (GTK_WINDOW (tool->main_dialog),
+				    GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+				    GTK_MESSAGE_QUESTION,
+				    GTK_BUTTONS_NONE,
+				    _("Are you sure you want to delete \"%s\"?"), label);
+	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (d),
+						  _("This may leave this operating system unbootable"));
+	gtk_dialog_add_buttons (GTK_DIALOG (d),
 				GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 				GTK_STOCK_DELETE, GTK_RESPONSE_ACCEPT,
 				NULL);
-	gst_hig_dialog_set_primary_text (GST_HIG_DIALOG (d),
-					 _("Are you sure you want to delete \"%s\"?"), label);
 
 	reply = gtk_dialog_run (GTK_DIALOG (d));
-
 	gtk_widget_destroy (d);
 	g_free (label);
 
@@ -458,15 +457,13 @@ callbacks_conf_read_failed_hook (GstTool *tool, GstReportLine *rline, gpointer d
 {
 	GtkWidget *dialog;
 
-	dialog = gst_hig_dialog_new (GTK_WINDOW (tool->main_dialog),
-				     GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-				     GST_HIG_MESSAGE_ERROR,
-				     _("The configuration will show empty"),
-				     NULL,
-				     GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
-				     NULL);
-	gst_hig_dialog_set_primary_text (GST_HIG_DIALOG (dialog),
-					 _("The file \"%s\" is missing or could not be read"), rline->argv[0]);
+	dialog = gtk_message_dialog_new (GTK_WINDOW (tool->main_dialog),
+					 GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+					 GTK_MESSAGE_ERROR,
+					 GTK_BUTTONS_CLOSE,
+					 _("The configuration will show empty"));
+	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
+						  _("The file \"%s\" is missing or could not be read"), rline->argv[0]);
 	gtk_dialog_run (GTK_DIALOG (dialog));
 	gtk_widget_destroy (dialog);
 
