@@ -38,7 +38,6 @@
 enum {
 	BOGUS,
 	APPLY,
-	COMPLEXITY_CHANGE,
 	LAST_SIGNAL
 };
 
@@ -67,9 +66,7 @@ gst_dialog_apply_widget_policies (GstDialog *xd)
 {
 	GSList *list;
 
-	/* Hide, show + desensitize or show + sensitize widgets based on access level
-	 * and complexity */
-
+	/* Hide, show + desensitize or show + sensitize widgets based on access level */
 	for (list = xd->gst_widget_list; list; list = g_slist_next (list))
 	{
 		gst_widget_apply_policy (list->data);
@@ -82,47 +79,7 @@ gst_dialog_get_complexity (GstDialog *xd)
 	g_return_val_if_fail (xd != NULL, 0);
 	g_return_val_if_fail (GST_IS_DIALOG (xd), 0);
 
-	return xd->complexity;
-}
-
-void
-gst_dialog_set_complexity (GstDialog *xd, GstDialogComplexity c)
-{
-	gchar *label[] = {
-		N_(" More _Options"),
-		N_(" Less _Options"),
-		NULL
-	};
-
-	gchar *image[] = {
-		GTK_STOCK_ADD,
-		GTK_STOCK_REMOVE,
-		NULL
-	};
-
-	g_return_if_fail (xd != NULL);
-	g_return_if_fail (GST_IS_DIALOG (xd));
-	g_return_if_fail (c >= GST_DIALOG_BASIC);
-	g_return_if_fail (c <= GST_DIALOG_ADVANCED);
-
-	if (xd->complexity == c)
-		return;
-
-	xd->complexity = c;
-
-	if (xd->complexity == GST_DIALOG_ADVANCED)
-		gst_conf_set_boolean (xd->tool, "advanced_mode", TRUE);
-	else
-		gst_conf_set_boolean (xd->tool, "advanced_mode", FALSE);
-
-	gst_dialog_apply_widget_policies (xd);
-
-	/* set the complexity button appearance */
-	gtk_label_set_text (GTK_LABEL (xd->complexity_button_label), _(label[c]));
-	gtk_label_set_use_underline (GTK_LABEL (xd->complexity_button_label), TRUE);
-	gtk_image_set_from_stock (GTK_IMAGE (xd->complexity_button_image), image[c], GTK_ICON_SIZE_MENU);
-
-	g_signal_emit (G_OBJECT (xd), gstdialog_signals[COMPLEXITY_CHANGE], 0);
+	return GST_DIALOG_ADVANCED;
 }
 
 void
@@ -150,10 +107,18 @@ gst_dialog_thaw (GstDialog *xd)
 void
 gst_dialog_freeze_visible (GstDialog *xd)
 {
+	GdkCursor *cursor;
+	
 	g_return_if_fail (xd != NULL);
 	g_return_if_fail (GST_IS_DIALOG (xd));
 	g_return_if_fail (xd->frozen >= 0);
 
+	if (GTK_WIDGET (xd)->window) {
+		cursor = gdk_cursor_new (GDK_WATCH);
+		gdk_window_set_cursor (GTK_WIDGET (xd)->window, cursor);
+		gdk_cursor_unref (cursor);
+	}
+
 	if (!xd->frozen)
 		gtk_widget_set_sensitive (GTK_WIDGET (xd), FALSE);
 	
@@ -167,6 +132,9 @@ gst_dialog_thaw_visible (GstDialog *xd)
 	g_return_if_fail (GST_IS_DIALOG (xd));
 	g_return_if_fail (xd->frozen >= 0);
 
+	if (GTK_WIDGET (xd)->window)
+		gdk_window_set_cursor (GTK_WIDGET (xd)->window, NULL);
+
 	gst_dialog_thaw (xd);
 
 	if (!xd->frozen)
@@ -179,7 +147,7 @@ gst_dialog_get_modified (GstDialog *xd)
 	g_return_val_if_fail (xd != NULL, FALSE);
 	g_return_val_if_fail (GST_IS_DIALOG (xd), FALSE);
 
-	return GTK_WIDGET_SENSITIVE (xd->apply_button);
+	return xd->is_modified;
 }
 
 void
@@ -188,7 +156,7 @@ gst_dialog_set_modified (GstDialog *xd, gboolean state)
 	g_return_if_fail (xd != NULL);
 	g_return_if_fail (GST_IS_DIALOG (xd));
 
-	gtk_widget_set_sensitive (xd->apply_button, state);
+	xd->is_modified = state;
 }
 
 void
@@ -212,62 +180,22 @@ gst_dialog_modify_cb (GtkWidget *w, gpointer data)
 }
 
 static void
-gst_dialog_destroy (GtkObject *tool)
+gst_dialog_class_init (GstDialogClass *class)
 {
-	GTK_OBJECT_CLASS (parent_class)->destroy (GTK_OBJECT (tool));
-}
+	GObjectClass *gobject_class;
 
-static void
-gst_dialog_class_init (GstDialogClass *klass)
-{
-	GtkObjectClass *object_class;
+	gobject_class = G_OBJECT_CLASS (class);
+	parent_class = g_type_class_peek_parent (class);
 
-	object_class = (GtkObjectClass *)klass;
-	parent_class = gtk_type_class (GNOME_TYPE_APP);
-
-#if 1	
 	gstdialog_signals[APPLY] = 
 		g_signal_new ("apply",
-			      G_OBJECT_CLASS_TYPE (object_class),
+			      G_OBJECT_CLASS_TYPE (gobject_class),
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (GstDialogClass, apply),
 			      NULL, NULL,
 			      gst_marshal_VOID__VOID,
 			      G_TYPE_NONE,
 			      0);
-	
-	gstdialog_signals[COMPLEXITY_CHANGE] =
-		g_signal_new ("complexity_change",
-			      G_OBJECT_CLASS_TYPE (object_class),
-			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (GstDialogClass, complexity_change),
-			      NULL, NULL,
-			      gst_marshal_VOID__VOID,
-			      G_TYPE_NONE,
-			      0);
-#else	
-	gstdialog_signals[APPLY] = 
-		gtk_signal_new ("apply",
-				GTK_RUN_LAST,
-				object_class->type,
-				GTK_SIGNAL_OFFSET (GstDialogClass, apply),
-				gtk_marshal_NONE__NONE,
-				GTK_TYPE_NONE, 0);
-
-	gstdialog_signals[COMPLEXITY_CHANGE] =
-		gtk_signal_new ("complexity_change",
-				GTK_RUN_LAST,
-				object_class->type,
-				GTK_SIGNAL_OFFSET (GstDialogClass, complexity_change),
-				gtk_marshal_NONE__NONE,
-				GTK_TYPE_NONE, 0);
-#endif	
-
-#if 0
-	gtk_object_class_add_signals (object_class, gstdialog_signals, LAST_SIGNAL);
-#endif	
-
-	object_class->destroy = gst_dialog_destroy;
 }
 
 static void
@@ -283,8 +211,8 @@ gst_dialog_get_type (void)
 {
 	static GType gstdialog_type = 0;
 
-	if (gstdialog_type == 0) {
-		GTypeInfo gstdialog_info = {
+	if (!gstdialog_type) {
+		static const GTypeInfo gstdialog_info = {
 			sizeof (GstDialogClass),
 			NULL, /* base_init */
 			NULL, /* base finalize */
@@ -419,29 +347,7 @@ gst_dialog_widget_set_user_sensitive (GstDialog *xd, const gchar *name, gboolean
 }
 
 static void
-complexity_cb (GtkWidget *w, gpointer data)
-{
-	GstDialog *dialog;
-
-	g_return_if_fail (data != NULL);
-	g_return_if_fail (GST_IS_DIALOG (data));
-
-	dialog = GST_DIALOG (data);
-
-	switch (dialog->complexity) {
-	case GST_DIALOG_BASIC:
-		gst_dialog_set_complexity (dialog, GST_DIALOG_ADVANCED);
-		break;
-	case GST_DIALOG_ADVANCED:
-		gst_dialog_set_complexity (dialog, GST_DIALOG_BASIC);
-		break;
-	default:
-		break;
-	}
-}
-
-static void
-apply_cb (GtkWidget *w, gpointer data)
+apply_config (gpointer data)
 {
 	GstDialog *dialog;
 
@@ -461,27 +367,31 @@ apply_cb (GtkWidget *w, gpointer data)
 void
 gst_dialog_ask_apply (GstDialog *dialog)
 {
-	g_return_if_fail (dialog != NULL);
-	g_return_if_fail (GST_IS_DIALOG (dialog));
+        g_return_if_fail (dialog != NULL);
+        g_return_if_fail (GST_IS_DIALOG (dialog));
 
-	if (gst_dialog_get_modified (dialog)) {
-		/* Changes have been made. */
-		GtkWidget *w;
-		gint       res;
+        if (gst_dialog_get_modified (dialog)) {
+                /* Changes have been made. */
+                GtkWidget *w;
+                gint       res;
 
 		w = gtk_message_dialog_new (GTK_WINDOW (dialog),
 					    GTK_DIALOG_MODAL,
 					    GTK_MESSAGE_QUESTION,
-					    GTK_BUTTONS_YES_NO,
-					    _("There are changes which haven't been applied.\n"
-					      "Apply them now?"));
-
-		res = gtk_dialog_run (GTK_DIALOG (w));
-		gtk_widget_destroy (w);
-
-		if (res == GTK_RESPONSE_YES)
-			apply_cb (NULL, dialog);
-	}
+					    GTK_BUTTONS_NONE,
+					    _("There are changes which have not been applied"));
+		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (w),
+							  _("Apply them now?"));
+		gtk_dialog_add_buttons (GTK_DIALOG (w),
+					GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+					GTK_STOCK_APPLY, GTK_RESPONSE_APPLY,
+					NULL);
+                res = gtk_dialog_run (GTK_DIALOG (w));
+                gtk_widget_destroy (w);
+                                                                                
+                if (res == GTK_RESPONSE_APPLY)
+                        apply_config (dialog);
+        }
 }
 
 static void
@@ -490,32 +400,15 @@ dialog_close (GstDialog *dialog)
 	g_return_if_fail (dialog != NULL);
 	g_return_if_fail (GST_IS_DIALOG (dialog));
 
-	gst_dialog_ask_apply (dialog);
-
 	gtk_widget_hide (GTK_WIDGET (dialog));
 
 	if (dialog == dialog->tool->main_dialog)
-		g_signal_emit_by_name (GTK_OBJECT (dialog->tool), "close");
+		g_signal_emit_by_name (G_OBJECT (dialog->tool), "close");
 }
 
 static void
-dialog_delete_event_cb (GtkWidget *w, GdkEvent *event, gpointer data)
+cancel_cb (GtkWidget *w, gpointer data)
 {
-	dialog_close (data);
-}
-
-static void
-close_cb (GtkWidget *w, gpointer data)
-{
-	dialog_close (data);
-}
-
-static void
-help_cb (GtkWidget *w, gpointer data)
-{
-#warning FIXME	
-#if 0
-	GnomeHelpMenuEntry help_entry = { NULL, "index.html" };
 	GstDialog *dialog;
 
 	g_return_if_fail (data != NULL);
@@ -523,23 +416,50 @@ help_cb (GtkWidget *w, gpointer data)
 
 	dialog = GST_DIALOG (data);
 
-	help_entry.name = g_strdup_printf ("%s-admin", dialog->tool->name);
-
-	gnome_help_display (NULL, &help_entry);
-
-	g_free (help_entry.name);
-#else
-	g_warning ("FIXME ! Port help_cb to 2.0\n");
-#endif
+	dialog_close (dialog);
 }
 
-void
-gst_dialog_enable_complexity (GstDialog *dialog)
+static void
+accept_cb (GtkWidget *w, gpointer data)
 {
-	g_return_if_fail (dialog != NULL);
-	g_return_if_fail (GST_IS_DIALOG (dialog));
+	GstDialog *dialog;
+	
+	g_return_if_fail (data != NULL);
+	g_return_if_fail (GST_IS_DIALOG (data));
 
-	gtk_widget_show (dialog->complexity_button);
+	dialog = GST_DIALOG (data);
+
+	if (gst_dialog_get_modified (dialog))
+		apply_config (dialog);
+	
+	dialog_close (dialog);
+}
+
+static void
+help_cb (GtkWidget *w, gpointer data)
+{
+	GstDialog *gst_dialog;
+
+	gst_dialog = GST_DIALOG (data);
+	gst_tool_show_help (gst_dialog->tool, NULL);
+}
+
+static gboolean
+dialog_delete_event_cb (GtkWidget *w, GdkEvent *event, gpointer data)
+{
+	cancel_cb (w, data);
+	return TRUE;
+}
+
+static gboolean
+dialog_key_press_event_cb (GtkWidget *w, GdkEventKey *event, gpointer data)
+{
+	if (event->keyval == GDK_Escape) {
+		cancel_cb (w, data);
+		return TRUE;
+	}
+
+	return FALSE;
 }
 
 static void
@@ -589,11 +509,10 @@ void
 gst_dialog_construct (GstDialog *dialog, GstTool *tool,
 		      const char *widget, const char *title)
 {
-	GladeXML *xml;
-	GtkWidget *w;
-	GtkStockItem item;
-	gboolean val;
-	char *s;
+	GladeXML     *xml;
+	GtkWidget    *w;
+	char         *s;
+	GtkSizeGroup *size_group;
 
 	g_return_if_fail (dialog != NULL);
 	g_return_if_fail (GST_IS_DIALOG (dialog));
@@ -618,51 +537,32 @@ gst_dialog_construct (GstDialog *dialog, GstTool *tool,
 
 	if (GTK_WIDGET_TOPLEVEL (dialog->child)) {
 		g_error ("The widget \"%s\" should not be a toplevel widget in the .glade file\n"
-			 "You just need to add the widget inside a GtkWindow so that it can be deparented it.", widget);
+			 "You just need to add the widget inside a GtkWindow so that it can be deparented.", widget);
 	}
 
 	gtk_widget_ref (dialog->child);
 	gtk_widget_unparent (dialog->child);
 	gtk_box_pack_start (GTK_BOX (w), dialog->child, TRUE, TRUE, 0);
 
+	size_group = gtk_size_group_new (GTK_SIZE_GROUP_BOTH);
+
 	w = glade_xml_get_widget (xml, "help");
 	g_signal_connect (G_OBJECT (w), "clicked", G_CALLBACK (help_cb), dialog);
-	/* FIXME: help button hidden until the help files are ready. */
-	gtk_widget_hide (w);
+	gtk_size_group_add_widget (size_group, w);
 
-	w = glade_xml_get_widget (xml, "complexity");
-	g_signal_connect (GTK_OBJECT (w), "clicked", G_CALLBACK (complexity_cb), dialog);
+	w = glade_xml_get_widget (xml, "cancel");
+	g_signal_connect (G_OBJECT (w), "clicked", G_CALLBACK (cancel_cb), dialog);
+	gtk_size_group_add_widget (size_group, w);
 
-	dialog->complexity_button = w;
-
-	w = glade_xml_get_widget (xml, "complexity_button_label");
-	dialog->complexity_button_label = w;
-
-	w = glade_xml_get_widget (xml, "complexity_button_image");
-	dialog->complexity_button_image = w;
-
-	w = glade_xml_get_widget (xml, "apply");
-	g_signal_connect (G_OBJECT (w), "clicked", G_CALLBACK (apply_cb), dialog);
-
-	dialog->apply_button = w;
-
-	w = glade_xml_get_widget (xml, "close");
-	g_signal_connect (GTK_OBJECT (w), "clicked", G_CALLBACK (close_cb), dialog);
+	w = glade_xml_get_widget (xml, "accept");
+	g_signal_connect (G_OBJECT (w), "clicked", G_CALLBACK (accept_cb), dialog);
+	gtk_size_group_add_widget (size_group, w);
 	
 	gst_dialog_set_modified (dialog, FALSE);
-	gtk_widget_hide (dialog->complexity_button);
-
-	dialog->complexity = GST_DIALOG_NONE;
-	val = gst_conf_get_boolean (dialog->tool, "advanced_mode");
-	if (val == FALSE)
-		val = GST_DIALOG_BASIC;
-
-	gst_dialog_set_complexity (dialog, val);
 
 	g_signal_connect (G_OBJECT (dialog), "delete_event", G_CALLBACK (dialog_delete_event_cb), dialog);
-
 	g_signal_connect (G_OBJECT (tool->remote_dialog), "delete_event", G_CALLBACK (dialog_delete_event_cb), dialog);
-
+	g_signal_connect (G_OBJECT (dialog), "key-press-event", G_CALLBACK (dialog_key_press_event_cb), dialog);
 }
 
 GstDialog *
