@@ -46,8 +46,10 @@ static GstDialogSignal signals [] = {
 	{ "share_type",               "changed",      G_CALLBACK (on_share_type_changed) },
 	{ "share_nfs_delete",         "clicked",      G_CALLBACK (on_share_nfs_delete_clicked) },
 	{ "share_nfs_add",            "clicked",      G_CALLBACK (on_share_nfs_add_clicked) },
+	{ "share_smb_settings",       "clicked",      G_CALLBACK (on_share_smb_settings_clicked) },
 	/* NFS add hosts dialog */
 	{ "share_nfs_host_type",      "changed",      G_CALLBACK (on_share_nfs_host_type_changed) },
+	/* SMB settings dialog */
 	{ NULL }
 };
 
